@@ -1,10 +1,13 @@
+extern crate alloc;
+
 pub mod server;
 pub mod state;
 
+use alloc::sync::Arc;
+use once_cell::sync::Lazy;
 use std::{
     error::Error,
     net::{SocketAddr, ToSocketAddrs},
-    sync::Arc,
     thread::JoinHandle,
 };
 
@@ -14,6 +17,12 @@ pub fn new_state() -> Arc<TelemetryState> {
     Arc::new(TelemetryState::default())
 }
 
+static GLOBAL_STATE: Lazy<Arc<TelemetryState>> = Lazy::new(new_state);
+
+pub fn global() -> &'static Arc<TelemetryState> {
+    &GLOBAL_STATE
+}
+
 pub fn spawn<A>(
     address: A,
     state: Arc<TelemetryState>,
